@@ -553,8 +553,8 @@ preprocess_gweather_reports (GcalWeatherService *self,
   /* Produce GcalWeatherInfo for each bucket: */
   for (i = 0; i < self->max_days; i++)
     {
-      g_autofree gchar *icon_name;
-      g_autofree gchar *temperature;
+      g_autofree gchar *temperature = NULL;
+      g_autofree gchar *icon_name = NULL;
 
       if (compute_weather_info_data (days[i], i == 0, &icon_name, &temperature))
         g_ptr_array_add (result, gcal_weather_info_new (&cur_gdate, icon_name, temperature));
@@ -638,12 +638,10 @@ update_location (GcalWeatherService  *self,
 
       self->gweather_info = gweather_info_new (location);
 
-      /*
-       * NOTE: We do not get detailed infos for GWEATHER_PROVIDER_ALL.
-       * This combination works fine, though. We should open a bug / investigate
-       * what is going on.
+      /* FIXME: Enable GWEATHER_PROVIDER_MET_NO if we can comply with their terms of service.
+       * https://gitlab.gnome.org/GNOME/gnome-calendar/-/issues/682
        */
-      gweather_info_set_enabled_providers (self->gweather_info, GWEATHER_PROVIDER_METAR | GWEATHER_PROVIDER_OWM | GWEATHER_PROVIDER_YR_NO);
+      gweather_info_set_enabled_providers (self->gweather_info, GWEATHER_PROVIDER_METAR | GWEATHER_PROVIDER_OWM);
       g_signal_connect_object (self->gweather_info, "updated", (GCallback) on_gweather_update_cb, self, 0);
 
       /*
